#!/bin/sh
#
# Enigma2 Control Script for OpenPLi
#
# This script provides functions to safely stop and start Enigma2
# without depending on systemd
#

# Function to stop Enigma2
stop_enigma2() {
    echo "Stopping Enigma2..."
    
    # Try init 4 first (standard OpenPLi way to stop GUI)
    if [ -x "$(command -v init)" ]; then
        init 4
        sleep 2
        return 0
    fi
    
    # Try init.d script if available
    if [ -f "/etc/init.d/enigma2" ]; then
        /etc/init.d/enigma2 stop
        sleep 2
        return 0
    fi
    
    # Last resort: killall
    if [ -x "$(command -v killall)" ]; then
        killall enigma2
        sleep 2
        return 0
    fi
    
    echo "Failed to stop Enigma2! No suitable method found."
    return 1
}

# Function to start Enigma2
start_enigma2() {
    echo "Starting Enigma2..."
    
    # Try init 3 first (standard OpenPLi way to start GUI)
    if [ -x "$(command -v init)" ]; then
        init 3
        return 0
    fi
    
    # Try init.d script if available
    if [ -f "/etc/init.d/enigma2" ]; then
        /etc/init.d/enigma2 start
        return 0
    fi
    
    # Last resort: direct start
    if [ -x "/usr/bin/enigma2" ]; then
        /usr/bin/enigma2 &
        return 0
    fi
    
    echo "Failed to start Enigma2! No suitable method found."
    return 1
}

# Function to check if Enigma2 is running
is_enigma2_running() {
    if [ -x "$(command -v pidof)" ]; then
        if pidof enigma2 > /dev/null; then
            return 0  # Running
        else
            return 1  # Not running
        fi
    else
        # Alternative method if pidof not available
        if ps | grep -v grep | grep "enigma2" > /dev/null; then
            return 0  # Running
        else
            return 1  # Not running
        fi
    fi
}

# Test functions if script is run directly
if [ "$1" = "stop" ]; then
    stop_enigma2
elif [ "$1" = "start" ]; then
    start_enigma2
elif [ "$1" = "restart" ]; then
    stop_enigma2
    start_enigma2
elif [ "$1" = "status" ]; then
    if is_enigma2_running; then
        echo "Enigma2 is running"
    else
        echo "Enigma2 is not running"
    fi
else
    echo "Usage: $0 {start|stop|restart|status}"
fi